@@ -1,7 +1,7 @@
 #!/bin/bash
 
 function bootstrap_db {
-    mysqld_safe --wsrep-new-cluster --skip-networking --wsrep-on=OFF &
+    mysqld_safe --wsrep-new-cluster --skip-networking --wsrep-on=OFF --pid-file=/var/lib/mysql/mariadb.pid &
     # Wait for the mariadb server to be "Ready" before starting the security reset with a max timeout
     # NOTE(huikang): the location of mysql's socket file varies depending on the OS distributions.
     # Querying the cluster status has to be executed after the existence of mysql.sock and mariadb.pid.
@@ -19,9 +19,8 @@ function bootstrap_db {
 # NOTE(sbezverk): Currently kolla-kubernetes does not use Galera and disables wsrep driver.
 # This check will run only for non kolla-kubernetes bootstrap deployments.
     if [[ ! "${!KOLLA_KUBERNETES[@]}" ]]; then
-        CLUSTER_READY=$(mysql -u root --exec="SHOW STATUS LIKE 'wsrep_ready'" | grep ON)
         TIMEOUT=${DB_MAX_TIMEOUT:-60}
-        while [[ -z "${CLUSTER_READY}" ]]; do
+        while [ $(mysql -u root -e "SHOW STATUS LIKE 'wsrep_ready'" | tail -n 1 | cut -f 2) != "ON" ]; do
             if [[ ${TIMEOUT} -gt 0 ]]; then
                 let TIMEOUT-=1
                 sleep 1
